# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.functions.v1 import function_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2
from yandex.cloud.serverless.functions.v1 import function_service_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2


class FunctionServiceStub(object):
    """A set of methods for managing serverless functions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/Get',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Function.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/List',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/Create',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/Update',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.UpdateFunctionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/Delete',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersion',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
                )
        self.GetVersionByTag = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersionByTag',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionByTagRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
                )
        self.ListVersions = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListVersions',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsResponse.FromString,
                )
        self.DeleteVersion = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/DeleteVersion',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.SetTag = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/SetTag',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetFunctionTagRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveTag = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/RemoveTag',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveFunctionTagRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListTagHistory = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListTagHistory',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryResponse.FromString,
                )
        self.CreateVersion = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/CreateVersion',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListRuntimes = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListRuntimes',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesResponse.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListScalingPolicies = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/ListScalingPolicies',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesResponse.FromString,
                )
        self.SetScalingPolicy = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/SetScalingPolicy',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetScalingPolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveScalingPolicy = channel.unary_unary(
                '/yandex.cloud.serverless.functions.v1.FunctionService/RemoveScalingPolicy',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveScalingPolicyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class FunctionServiceServicer(object):
    """A set of methods for managing serverless functions.
    """

    def Get(self, request, context):
        """Returns the specified function.

        To get the list of all available functions, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of functions in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a function in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Returns the specified version of a function.

        To get the list of available version, make a [ListVersions] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersionByTag(self, request, context):
        """Returns all versions with the specified tag.

        To get the list of all available versions, make a [ListVersions] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVersions(self, request, context):
        """Retrieves the list of versions for the specified function, or of all function versions
        in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVersion(self, request, context):
        """Deletes the specified version of a function.

        NOTE: old untagged function versions are deleted automatically.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTag(self, request, context):
        """Set a tag for the specified version of a function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTag(self, request, context):
        """Remove a tag from the specified version of a function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTagHistory(self, request, context):
        """Returns the log of tags assigned to versions of the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVersion(self, request, context):
        """Creates a version for the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRuntimes(self, request, context):
        """Lists available runtime environments for the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScalingPolicies(self, request, context):
        """Lists existing scaling policies for specified function
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetScalingPolicy(self, request, context):
        """Set scaling policy for specified function and tag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveScalingPolicy(self, request, context):
        """Remove scaling policy for specified function and tag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FunctionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Function.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.UpdateFunctionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.SerializeToString,
            ),
            'GetVersionByTag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersionByTag,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionByTagRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.SerializeToString,
            ),
            'ListVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVersions,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsResponse.SerializeToString,
            ),
            'DeleteVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVersion,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetTag': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTag,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetFunctionTagRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveTag': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTag,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveFunctionTagRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListTagHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTagHistory,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryResponse.SerializeToString,
            ),
            'CreateVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVersion,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListRuntimes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRuntimes,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListScalingPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScalingPolicies,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesResponse.SerializeToString,
            ),
            'SetScalingPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.SetScalingPolicy,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetScalingPolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveScalingPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveScalingPolicy,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveScalingPolicyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.functions.v1.FunctionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FunctionService(object):
    """A set of methods for managing serverless functions.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/Get',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Function.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/List',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/Create',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/Update',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.UpdateFunctionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/Delete',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersion',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersionByTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/GetVersionByTag',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.GetFunctionVersionByTagRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2.Version.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListVersions',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionsVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/DeleteVersion',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.DeleteFunctionVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/SetTag',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetFunctionTagRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/RemoveTag',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveFunctionTagRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTagHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListTagHistory',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionTagHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/CreateVersion',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.CreateFunctionVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRuntimes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListRuntimes',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListRuntimesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListOperations',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListFunctionOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScalingPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/ListScalingPolicies',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.ListScalingPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetScalingPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/SetScalingPolicy',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.SetScalingPolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveScalingPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.functions.v1.FunctionService/RemoveScalingPolicy',
            yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__service__pb2.RemoveScalingPolicyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/dataset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/datasphere/v2/dataset.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x02\n\x07\x44\x61taset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.yandex.cloud.datasphere.v2.Dataset.LabelsEntry\x12\x15\n\rcreated_by_id\x18\x07 \x01(\t\x12\x0c\n\x04\x63ode\x18\x08 \x01(\t\x12\x0f\n\x07size_gb\x18\t \x01(\x03\x12\x10\n\x08zone_ids\x18\n \x03(\t\x12\x12\n\nmount_path\x18\x0b \x01(\t\x12\x17\n\x0f\x64\x61ta_capsule_id\x18\x0c \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n\rDatasetStatus\x12O\n\rstatus_active\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datasphere.v2.DatasetStatus.StatusActiveH\x00\x12S\n\x0fstatus_inactive\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.datasphere.v2.DatasetStatus.StatusInactiveH\x00\x12M\n\x0cstatus_error\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.datasphere.v2.DatasetStatus.StatusErrorH\x00\x1a\x0e\n\x0cStatusActive\x1a\x10\n\x0eStatusInactive\x1a\x1c\n\x0bStatusError\x12\r\n\x05\x65rror\x18\x01 \x01(\tB\x08\n\x06statusBk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.dataset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _DATASET_LABELSENTRY._options = None
  _DATASET_LABELSENTRY._serialized_options = b'8\001'
  _globals['_DATASET']._serialized_start=106
  _globals['_DATASET']._serialized_end=459
  _globals['_DATASET_LABELSENTRY']._serialized_start=414
  _globals['_DATASET_LABELSENTRY']._serialized_end=459
  _globals['_DATASETSTATUS']._serialized_start=462
  _globals['_DATASETSTATUS']._serialized_end=796
  _globals['_DATASETSTATUS_STATUSACTIVE']._serialized_start=724
  _globals['_DATASETSTATUS_STATUSACTIVE']._serialized_end=738
  _globals['_DATASETSTATUS_STATUSINACTIVE']._serialized_start=740
  _globals['_DATASETSTATUS_STATUSINACTIVE']._serialized_end=756
  _globals['_DATASETSTATUS_STATUSERROR']._serialized_start=758
  _globals['_DATASETSTATUS_STATUSERROR']._serialized_end=786
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/origin_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/cdn/v1/origin_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"N\n\x10GetOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"V\n\x12ListOriginsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"C\n\x13ListOriginsResponse\x12,\n\x07origins\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.cdn.v1.Origin\"\xfd\x01\n\x13\x43reateOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1c\n\x06source\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x62\x61\x63kup\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x04meta\x18\x06 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\"R\n\x14\x43reateOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xb1\x01\n\x13UpdateOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0e\n\x06\x62\x61\x63kup\x18\x05 \x01(\x08\x12-\n\x04meta\x18\x06 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\"R\n\x14UpdateOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"Q\n\x13\x44\x65leteOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"1\n\x14\x44\x65leteOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\xd9\x05\n\rOriginService\x12n\n\x03Get\x12%.yandex.cloud.cdn.v1.GetOriginRequest\x1a\x1b.yandex.cloud.cdn.v1.Origin\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cdn/v1/origins/{origin_id}\x12r\n\x04List\x12\'.yandex.cloud.cdn.v1.ListOriginsRequest\x1a(.yandex.cloud.cdn.v1.ListOriginsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/cdn/v1/origins\x12\x93\x01\n\x06\x43reate\x12(.yandex.cloud.cdn.v1.CreateOriginRequest\x1a!.yandex.cloud.operation.Operation\"<\xb2\xd2*\x1e\n\x14\x43reateOriginMetadata\x12\x06Origin\x82\xd3\xe4\x93\x02\x14\"\x0f/cdn/v1/origins:\x01*\x12\x9f\x01\n\x06Update\x12(.yandex.cloud.cdn.v1.UpdateOriginRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\x1e\n\x14UpdateOriginMetadata\x12\x06Origin\x82\xd3\xe4\x93\x02 2\x1b/cdn/v1/origins/{origin_id}:\x01*\x12\xab\x01\n\x06\x44\x65lete\x12(.yandex.cloud.cdn.v1.DeleteOriginRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*-\n\x14\x44\x65leteOriginMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/cdn/v1/origins/{origin_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.origin_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _GETORIGINREQUEST.fields_by_name['folder_id']._options = None
  _GETORIGINREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETORIGINREQUEST.fields_by_name['origin_id']._options = None
  _GETORIGINREQUEST.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _LISTORIGINSREQUEST.fields_by_name['folder_id']._options = None
  _LISTORIGINSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTORIGINSREQUEST.fields_by_name['origin_group_id']._options = None
  _LISTORIGINSREQUEST.fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _CREATEORIGINREQUEST.fields_by_name['folder_id']._options = None
  _CREATEORIGINREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEORIGINREQUEST.fields_by_name['origin_group_id']._options = None
  _CREATEORIGINREQUEST.fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _CREATEORIGINREQUEST.fields_by_name['source']._options = None
  _CREATEORIGINREQUEST.fields_by_name['source']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEORIGINMETADATA.fields_by_name['origin_id']._options = None
  _CREATEORIGINMETADATA.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _CREATEORIGINMETADATA.fields_by_name['origin_group_id']._options = None
  _CREATEORIGINMETADATA.fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _UPDATEORIGINREQUEST.fields_by_name['folder_id']._options = None
  _UPDATEORIGINREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEORIGINREQUEST.fields_by_name['origin_id']._options = None
  _UPDATEORIGINREQUEST.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _UPDATEORIGINMETADATA.fields_by_name['origin_id']._options = None
  _UPDATEORIGINMETADATA.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _UPDATEORIGINMETADATA.fields_by_name['origin_group_id']._options = None
  _UPDATEORIGINMETADATA.fields_by_name['origin_group_id']._serialized_options = b'\372\3071\002>0'
  _DELETEORIGINREQUEST.fields_by_name['folder_id']._options = None
  _DELETEORIGINREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEORIGINREQUEST.fields_by_name['origin_id']._options = None
  _DELETEORIGINREQUEST.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _DELETEORIGINMETADATA.fields_by_name['origin_id']._options = None
  _DELETEORIGINMETADATA.fields_by_name['origin_id']._serialized_options = b'\372\3071\002>0'
  _ORIGINSERVICE.methods_by_name['Get']._options = None
  _ORIGINSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/cdn/v1/origins/{origin_id}'
  _ORIGINSERVICE.methods_by_name['List']._options = None
  _ORIGINSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/cdn/v1/origins'
  _ORIGINSERVICE.methods_by_name['Create']._options = None
  _ORIGINSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateOriginMetadata\022\006Origin\202\323\344\223\002\024\"\017/cdn/v1/origins:\001*'
  _ORIGINSERVICE.methods_by_name['Update']._options = None
  _ORIGINSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateOriginMetadata\022\006Origin\202\323\344\223\002 2\033/cdn/v1/origins/{origin_id}:\001*'
  _ORIGINSERVICE.methods_by_name['Delete']._options = None
  _ORIGINSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteOriginMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/cdn/v1/origins/{origin_id}'
  _globals['_GETORIGINREQUEST']._serialized_start=266
  _globals['_GETORIGINREQUEST']._serialized_end=344
  _globals['_LISTORIGINSREQUEST']._serialized_start=346
  _globals['_LISTORIGINSREQUEST']._serialized_end=432
  _globals['_LISTORIGINSRESPONSE']._serialized_start=434
  _globals['_LISTORIGINSRESPONSE']._serialized_end=501
  _globals['_CREATEORIGINREQUEST']._serialized_start=504
  _globals['_CREATEORIGINREQUEST']._serialized_end=757
  _globals['_CREATEORIGINMETADATA']._serialized_start=759
  _globals['_CREATEORIGINMETADATA']._serialized_end=841
  _globals['_UPDATEORIGINREQUEST']._serialized_start=844
  _globals['_UPDATEORIGINREQUEST']._serialized_end=1021
  _globals['_UPDATEORIGINMETADATA']._serialized_start=1023
  _globals['_UPDATEORIGINMETADATA']._serialized_end=1105
  _globals['_DELETEORIGINREQUEST']._serialized_start=1107
  _globals['_DELETEORIGINREQUEST']._serialized_end=1188
  _globals['_DELETEORIGINMETADATA']._serialized_start=1190
  _globals['_DELETEORIGINMETADATA']._serialized_end=1239
  _globals['_ORIGINSERVICE']._serialized_start=1242
  _globals['_ORIGINSERVICE']._serialized_end=1971
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/ml_model_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import ml_model_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_ml__model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/mdb/clickhouse/v1/ml_model_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/mdb/clickhouse/v1/ml_model.proto\"l\n\x11GetMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"u\n\x13ListMlModelsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x14ListMlModelsResponse\x12:\n\tml_models\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.clickhouse.v1.MlModel\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x01\n\x14\x43reateMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12?\n\x04type\x18\x03 \x01(\x0e\x32+.yandex.cloud.mdb.clickhouse.v1.MlModelTypeB\x04\xe8\xc7\x31\x01\x12\x11\n\x03uri\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"B\n\x15\x43reateMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t\"\xad\x01\n\x14UpdateMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0b\n\x03uri\x18\x04 \x01(\t\"B\n\x15UpdateMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t\"o\n\x14\x44\x65leteMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"B\n\x15\x44\x65leteMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t2\xff\x07\n\x0eMlModelService\x12\xb0\x01\n\x03Get\x12\x31.yandex.cloud.mdb.clickhouse.v1.GetMlModelRequest\x1a\'.yandex.cloud.mdb.clickhouse.v1.MlModel\"M\x82\xd3\xe4\x93\x02G\x12\x45/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}\x12\xb0\x01\n\x04List\x12\x33.yandex.cloud.mdb.clickhouse.v1.ListMlModelsRequest\x1a\x34.yandex.cloud.mdb.clickhouse.v1.ListMlModelsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-clickhouse/v1/clusters/{cluster_id}/mlModels\x12\xc7\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.clickhouse.v1.CreateMlModelRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2* \n\x15\x43reateMlModelMetadata\x12\x07MlModel\x82\xd3\xe4\x93\x02:\"5/managed-clickhouse/v1/clusters/{cluster_id}/mlModels:\x01*\x12\xd7\x01\n\x06Update\x12\x34.yandex.cloud.mdb.clickhouse.v1.UpdateMlModelRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2* \n\x15UpdateMlModelMetadata\x12\x07MlModel\x82\xd3\xe4\x93\x02J2E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}:\x01*\x12\xe2\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.clickhouse.v1.DeleteMlModelRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*.\n\x15\x44\x65leteMlModelMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.ml_model_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _GETMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _GETMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _GETMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTMLMODELSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTMLMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTMLMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATEMLMODELREQUEST.fields_by_name['type']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CREATEMLMODELREQUEST.fields_by_name['uri']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['uri']._serialized_options = b'\350\3071\001'
  _UPDATEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _UPDATEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _DELETEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _MLMODELSERVICE.methods_by_name['Get']._options = None
  _MLMODELSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002G\022E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}'
  _MLMODELSERVICE.methods_by_name['List']._options = None
  _MLMODELSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0027\0225/managed-clickhouse/v1/clusters/{cluster_id}/mlModels'
  _MLMODELSERVICE.methods_by_name['Create']._options = None
  _MLMODELSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateMlModelMetadata\022\007MlModel\202\323\344\223\002:\"5/managed-clickhouse/v1/clusters/{cluster_id}/mlModels:\001*'
  _MLMODELSERVICE.methods_by_name['Update']._options = None
  _MLMODELSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateMlModelMetadata\022\007MlModel\202\323\344\223\002J2E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}:\001*'
  _MLMODELSERVICE.methods_by_name['Delete']._options = None
  _MLMODELSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteMlModelMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}'
  _globals['_GETMLMODELREQUEST']._serialized_start=305
  _globals['_GETMLMODELREQUEST']._serialized_end=413
  _globals['_LISTMLMODELSREQUEST']._serialized_start=415
  _globals['_LISTMLMODELSREQUEST']._serialized_end=532
  _globals['_LISTMLMODELSRESPONSE']._serialized_start=534
  _globals['_LISTMLMODELSRESPONSE']._serialized_end=641
  _globals['_CREATEMLMODELREQUEST']._serialized_start=644
  _globals['_CREATEMLMODELREQUEST']._serialized_end=839
  _globals['_CREATEMLMODELMETADATA']._serialized_start=841
  _globals['_CREATEMLMODELMETADATA']._serialized_end=907
  _globals['_UPDATEMLMODELREQUEST']._serialized_start=910
  _globals['_UPDATEMLMODELREQUEST']._serialized_end=1083
  _globals['_UPDATEMLMODELMETADATA']._serialized_start=1085
  _globals['_UPDATEMLMODELMETADATA']._serialized_end=1151
  _globals['_DELETEMLMODELREQUEST']._serialized_start=1153
  _globals['_DELETEMLMODELREQUEST']._serialized_end=1264
  _globals['_DELETEMLMODELMETADATA']._serialized_start=1266
  _globals['_DELETEMLMODELMETADATA']._serialized_end=1332
  _globals['_MLMODELSERVICE']._serialized_start=1335
  _globals['_MLMODELSERVICE']._serialized_end=2358
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/saml/certificate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/organizationmanager/v1/saml/certificate.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x01\n\x0b\x43\x65rtificate\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rfederation_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x04\x64\x61ta\x18\x06 \x01(\tB\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32000B\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.saml.certificate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml'
  _CERTIFICATE.fields_by_name['id']._options = None
  _CERTIFICATE.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CERTIFICATE.fields_by_name['federation_id']._options = None
  _CERTIFICATE.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CERTIFICATE.fields_by_name['name']._options = None
  _CERTIFICATE.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CERTIFICATE.fields_by_name['description']._options = None
  _CERTIFICATE.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CERTIFICATE.fields_by_name['data']._options = None
  _CERTIFICATE.fields_by_name['data']._serialized_options = b'\350\3071\001\212\3101\007<=32000'
  _globals['_CERTIFICATE']._serialized_start=169
  _globals['_CERTIFICATE']._serialized_end=405
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/hba_rule_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.greenplum.v1 import hba_rule_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_hba__rule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/greenplum/v1/hba_rule_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/greenplum/v1/hba_rule.proto\"x\n\x14\x43reateHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08hba_rule\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x04\xe8\xc7\x31\x01\"x\n\x14UpdateHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08hba_rule\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x04\xe8\xc7\x31\x01\"V\n\x14\x44\x65leteHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x08priority\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\"7\n\x13ListHBARulesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"[\n\x1dListHBARulesAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08revision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"Q\n\x14ListHBARulesResponse\x12\x39\n\thba_rules\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARule\"\x81\x01\n\x1a\x42\x61tchUpdateHBARulesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\thba_rules\x18\x02 \x03(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x06\x82\xc8\x31\x02>0\"&\n\x10HBARulesMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t2\xf1\t\n\x0eHBARuleService\x12\xad\x01\n\x04List\x12\x32.yandex.cloud.mdb.greenplum.v1.ListHBARulesRequest\x1a\x33.yandex.cloud.mdb.greenplum.v1.ListHBARulesResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-greenplum/v1/clusters/{cluster_id}/hbaRules\x12\xcc\x01\n\x0eListAtRevision\x12<.yandex.cloud.mdb.greenplum.v1.ListHBARulesAtRevisionRequest\x1a\x33.yandex.cloud.mdb.greenplum.v1.ListHBARulesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/managed-greenplum/v1/clusters/{cluster_id}/hbaRules/atRevision\x12\xce\x01\n\x06\x43reate\x12\x33.yandex.cloud.mdb.greenplum.v1.CreateHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\x01*\x12\xce\x01\n\x06Update\x12\x33.yandex.cloud.mdb.greenplum.v1.UpdateHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\x32\x34/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.mdb.greenplum.v1.DeleteHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/managed-greenplum/v1/clusters/{cluster_id}/hbaRule/{priority}\x12\xe5\x01\n\x0b\x42\x61tchUpdate\x12\x39.yandex.cloud.mdb.greenplum.v1.BatchUpdateHBARulesRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:batchUpdate:\x01*Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _CREATEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEHBARULEREQUEST.fields_by_name['hba_rule']._options = None
  _CREATEHBARULEREQUEST.fields_by_name['hba_rule']._serialized_options = b'\350\3071\001'
  _UPDATEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEHBARULEREQUEST.fields_by_name['hba_rule']._options = None
  _UPDATEHBARULEREQUEST.fields_by_name['hba_rule']._serialized_options = b'\350\3071\001'
  _DELETEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEHBARULEREQUEST.fields_by_name['priority']._options = None
  _DELETEHBARULEREQUEST.fields_by_name['priority']._serialized_options = b'\372\3071\0060-1000'
  _LISTHBARULESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTHBARULESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['cluster_id']._options = None
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['revision']._options = None
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['cluster_id']._options = None
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['hba_rules']._options = None
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['hba_rules']._serialized_options = b'\202\3101\002>0'
  _HBARULESERVICE.methods_by_name['List']._options = None
  _HBARULESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0026\0224/managed-greenplum/v1/clusters/{cluster_id}/hbaRules'
  _HBARULESERVICE.methods_by_name['ListAtRevision']._options = None
  _HBARULESERVICE.methods_by_name['ListAtRevision']._serialized_options = b'\202\323\344\223\002A\022?/managed-greenplum/v1/clusters/{cluster_id}/hbaRules/atRevision'
  _HBARULESERVICE.methods_by_name['Create']._options = None
  _HBARULESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\001*'
  _HBARULESERVICE.methods_by_name['Update']._options = None
  _HBARULESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002924/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\001*'
  _HBARULESERVICE.methods_by_name['Delete']._options = None
  _HBARULESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/managed-greenplum/v1/clusters/{cluster_id}/hbaRule/{priority}'
  _HBARULESERVICE.methods_by_name['BatchUpdate']._options = None
  _HBARULESERVICE.methods_by_name['BatchUpdate']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:batchUpdate:\001*'
  _globals['_CREATEHBARULEREQUEST']._serialized_start=268
  _globals['_CREATEHBARULEREQUEST']._serialized_end=388
  _globals['_UPDATEHBARULEREQUEST']._serialized_start=390
  _globals['_UPDATEHBARULEREQUEST']._serialized_end=510
  _globals['_DELETEHBARULEREQUEST']._serialized_start=512
  _globals['_DELETEHBARULEREQUEST']._serialized_end=598
  _globals['_LISTHBARULESREQUEST']._serialized_start=600
  _globals['_LISTHBARULESREQUEST']._serialized_end=655
  _globals['_LISTHBARULESATREVISIONREQUEST']._serialized_start=657
  _globals['_LISTHBARULESATREVISIONREQUEST']._serialized_end=748
  _globals['_LISTHBARULESRESPONSE']._serialized_start=750
  _globals['_LISTHBARULESRESPONSE']._serialized_end=831
  _globals['_BATCHUPDATEHBARULESREQUEST']._serialized_start=834
  _globals['_BATCHUPDATEHBARULESREQUEST']._serialized_end=963
  _globals['_HBARULESMETADATA']._serialized_start=965
  _globals['_HBARULESMETADATA']._serialized_end=1003
  _globals['_HBARULESERVICE']._serialized_start=1006
  _globals['_HBARULESERVICE']._serialized_end=2271
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/functions/v1/function.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/serverless/functions/v1/function.proto\x12$yandex.cloud.serverless.functions.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xe1\x03\n\x08\x46unction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12T\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.serverless.functions.v1.Function.LabelsEntryB\x08\x82\xc8\x31\x04<=64\x12\x14\n\x0clog_group_id\x18\x07 \x01(\t\x12\x17\n\x0fhttp_invoke_url\x18\x08 \x01(\t\x12\x45\n\x06status\x18\t \x01(\x0e\x32\x35.yandex.cloud.serverless.functions.v1.Function.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"\xb8\t\n\x07Version\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x66unction_id\x18\x02 \x01(\t\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07runtime\x18\x06 \x01(\t\x12\x12\n\nentrypoint\x18\x07 \x01(\t\x12\x42\n\tresources\x18\x08 \x01(\x0b\x32/.yandex.cloud.serverless.functions.v1.Resources\x12\x34\n\x11\x65xecution_timeout\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x12\n\nimage_size\x18\x0c \x01(\x03\x12\x44\n\x06status\x18\r \x01(\x0e\x32\x34.yandex.cloud.serverless.functions.v1.Version.Status\x12\x0c\n\x04tags\x18\x0e \x03(\t\x12\x14\n\x0clog_group_id\x18\x0f \x01(\t\x12S\n\x0b\x65nvironment\x18\x10 \x03(\x0b\x32>.yandex.cloud.serverless.functions.v1.Version.EnvironmentEntry\x12H\n\x0c\x63onnectivity\x18\x11 \x01(\x0b\x32\x32.yandex.cloud.serverless.functions.v1.Connectivity\x12g\n\x16named_service_accounts\x18\x12 \x03(\x0b\x32G.yandex.cloud.serverless.functions.v1.Version.NamedServiceAccountsEntry\x12=\n\x07secrets\x18\x13 \x03(\x0b\x32,.yandex.cloud.serverless.functions.v1.Secret\x12\x45\n\x0blog_options\x18\x14 \x01(\x0b\x32\x30.yandex.cloud.serverless.functions.v1.LogOptions\x12J\n\x0estorage_mounts\x18\x15 \x03(\x0b\x32\x32.yandex.cloud.serverless.functions.v1.StorageMount\x12\\\n\x17\x61sync_invocation_config\x18\x16 \x01(\x0b\x32;.yandex.cloud.serverless.functions.v1.AsyncInvocationConfig\x12\x12\n\ntmpfs_size\x18\x17 \x01(\x03\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19NamedServiceAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02J\x04\x08\x0b\x10\x0cJ\x04\x08\x04\x10\x05\"5\n\tResources\x12(\n\x06memory\x18\x01 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x31\x33\x34\x32\x31\x37\x37\x32\x38-4294967296\"O\n\x07Package\x12\x19\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bobject_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06sha256\x18\x03 \x01(\t\"A\n\x0c\x43onnectivity\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x1d\n\tsubnet_id\x18\x02 \x03(\tB\n\x8a\xc8\x31\x02>0\x90\xc8\x31\x01\"\xf8\x01\n\rScalingPolicy\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x1bprovisioned_instances_count\x18\x06 \x01(\x03\x12\x1c\n\x14zone_instances_limit\x18\x07 \x01(\x03\x12\x1b\n\x13zone_requests_limit\x18\x08 \x01(\x03J\x04\x08\x05\x10\x06\"b\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x1e\n\x14\x65nvironment_variable\x18\x04 \x01(\tH\x00\x42\x0b\n\treference\"\xe0\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12;\n\x0clog_group_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x38\n\tfolder_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\"\x9f\x01\n\x0cStorageMount\x12\x31\n\tbucket_id\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[-.0-9a-zA-Z]*\x8a\xc8\x31\x04\x33-63\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x39\n\x10mount_point_name\x18\x03 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[-_0-9a-zA-Z]*\x8a\xc8\x31\x05\x31-100\x12\x11\n\tread_only\x18\x04 \x01(\x08\"\xde\x03\n\x15\x41syncInvocationConfig\x12 \n\rretries_count\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12h\n\x0esuccess_target\x18\x02 \x01(\x0b\x32J.yandex.cloud.serverless.functions.v1.AsyncInvocationConfig.ResponseTargetB\x04\xe8\xc7\x31\x01\x12h\n\x0e\x66\x61ilure_target\x18\x03 \x01(\x0b\x32J.yandex.cloud.serverless.functions.v1.AsyncInvocationConfig.ResponseTargetB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x1a\xb2\x01\n\x0eResponseTarget\x12I\n\x0c\x65mpty_target\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.serverless.functions.v1.EmptyTargetH\x00\x12\x45\n\nymq_target\x18\x02 \x01(\x0b\x32/.yandex.cloud.serverless.functions.v1.YMQTargetH\x00\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"N\n\tYMQTarget\x12\x17\n\tqueue_arn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\r\n\x0b\x45mptyTargetB~\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.functions.v1.function_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functions'
  _FUNCTION_LABELSENTRY._options = None
  _FUNCTION_LABELSENTRY._serialized_options = b'8\001'
  _FUNCTION.fields_by_name['name']._options = None
  _FUNCTION.fields_by_name['name']._serialized_options = b'\212\3101\0043-63'
  _FUNCTION.fields_by_name['description']._options = None
  _FUNCTION.fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _FUNCTION.fields_by_name['labels']._options = None
  _FUNCTION.fields_by_name['labels']._serialized_options = b'\202\3101\004<=64'
  _VERSION_ENVIRONMENTENTRY._options = None
  _VERSION_ENVIRONMENTENTRY._serialized_options = b'8\001'
  _VERSION_NAMEDSERVICEACCOUNTSENTRY._options = None
  _VERSION_NAMEDSERVICEACCOUNTSENTRY._serialized_options = b'8\001'
  _VERSION.fields_by_name['description']._options = None
  _VERSION.fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _RESOURCES.fields_by_name['memory']._options = None
  _RESOURCES.fields_by_name['memory']._serialized_options = b'\372\3071\024134217728-4294967296'
  _PACKAGE.fields_by_name['bucket_name']._options = None
  _PACKAGE.fields_by_name['bucket_name']._serialized_options = b'\350\3071\001'
  _PACKAGE.fields_by_name['object_name']._options = None
  _PACKAGE.fields_by_name['object_name']._serialized_options = b'\350\3071\001'
  _CONNECTIVITY.fields_by_name['subnet_id']._options = None
  _CONNECTIVITY.fields_by_name['subnet_id']._serialized_options = b'\212\3101\002>0\220\3101\001'
  _LOGOPTIONS.fields_by_name['log_group_id']._options = None
  _LOGOPTIONS.fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _LOGOPTIONS.fields_by_name['folder_id']._options = None
  _LOGOPTIONS.fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _STORAGEMOUNT.fields_by_name['bucket_id']._options = None
  _STORAGEMOUNT.fields_by_name['bucket_id']._serialized_options = b'\350\3071\001\362\3071\016[-.0-9a-zA-Z]*\212\3101\0043-63'
  _STORAGEMOUNT.fields_by_name['mount_point_name']._options = None
  _STORAGEMOUNT.fields_by_name['mount_point_name']._serialized_options = b'\350\3071\001\362\3071\016[-_0-9a-zA-Z]*\212\3101\0051-100'
  _ASYNCINVOCATIONCONFIG_RESPONSETARGET.oneofs_by_name['target']._options = None
  _ASYNCINVOCATIONCONFIG_RESPONSETARGET.oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _ASYNCINVOCATIONCONFIG.fields_by_name['retries_count']._options = None
  _ASYNCINVOCATIONCONFIG.fields_by_name['retries_count']._serialized_options = b'\372\3071\0050-100'
  _ASYNCINVOCATIONCONFIG.fields_by_name['success_target']._options = None
  _ASYNCINVOCATIONCONFIG.fields_by_name['success_target']._serialized_options = b'\350\3071\001'
  _ASYNCINVOCATIONCONFIG.fields_by_name['failure_target']._options = None
  _ASYNCINVOCATIONCONFIG.fields_by_name['failure_target']._serialized_options = b'\350\3071\001'
  _YMQTARGET.fields_by_name['queue_arn']._options = None
  _YMQTARGET.fields_by_name['queue_arn']._serialized_options = b'\350\3071\001'
  _YMQTARGET.fields_by_name['service_account_id']._options = None
  _YMQTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FUNCTION']._serialized_start=231
  _globals['_FUNCTION']._serialized_end=712
  _globals['_FUNCTION_LABELSENTRY']._serialized_start=582
  _globals['_FUNCTION_LABELSENTRY']._serialized_end=627
  _globals['_FUNCTION_STATUS']._serialized_start=629
  _globals['_FUNCTION_STATUS']._serialized_end=712
  _globals['_VERSION']._serialized_start=715
  _globals['_VERSION']._serialized_end=1923
  _globals['_VERSION_ENVIRONMENTENTRY']._serialized_start=1740
  _globals['_VERSION_ENVIRONMENTENTRY']._serialized_end=1790
  _globals['_VERSION_NAMEDSERVICEACCOUNTSENTRY']._serialized_start=1792
  _globals['_VERSION_NAMEDSERVICEACCOUNTSENTRY']._serialized_end=1851
  _globals['_VERSION_STATUS']._serialized_start=629
  _globals['_VERSION_STATUS']._serialized_end=687
  _globals['_RESOURCES']._serialized_start=1925
  _globals['_RESOURCES']._serialized_end=1978
  _globals['_PACKAGE']._serialized_start=1980
  _globals['_PACKAGE']._serialized_end=2059
  _globals['_CONNECTIVITY']._serialized_start=2061
  _globals['_CONNECTIVITY']._serialized_end=2126
  _globals['_SCALINGPOLICY']._serialized_start=2129
  _globals['_SCALINGPOLICY']._serialized_end=2377
  _globals['_SECRET']._serialized_start=2379
  _globals['_SECRET']._serialized_end=2477
  _globals['_LOGOPTIONS']._serialized_start=2480
  _globals['_LOGOPTIONS']._serialized_end=2704
  _globals['_STORAGEMOUNT']._serialized_start=2707
  _globals['_STORAGEMOUNT']._serialized_end=2866
  _globals['_ASYNCINVOCATIONCONFIG']._serialized_start=2869
  _globals['_ASYNCINVOCATIONCONFIG']._serialized_end=3347
  _globals['_ASYNCINVOCATIONCONFIG_RESPONSETARGET']._serialized_start=3169
  _globals['_ASYNCINVOCATIONCONFIG_RESPONSETARGET']._serialized_end=3347
  _globals['_YMQTARGET']._serialized_start=3349
  _globals['_YMQTARGET']._serialized_end=3427
  _globals['_EMPTYTARGET']._serialized_start=3429
  _globals['_EMPTYTARGET']._serialized_end=3442
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/config/host16_1c.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/mdb/postgresql/v1/config/host16_1c.proto\x12%yandex.cloud.mdb.postgresql.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x8c\x30\n\x19PostgresqlHostConfig16_1C\x12=\n\x18recovery_min_apply_delay\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0eshared_buffers\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0ctemp_buffers\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08work_mem\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0ftemp_file_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x13\x62\x61\x63kend_flush_after\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-2048\x12I\n\x16old_snapshot_threshold\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08-1-86400\x12@\n\x1bmax_standby_streaming_delay\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12r\n\x14\x63onstraint_exclusion\x18\t \x01(\x0e\x32T.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.ConstraintExclusion\x12;\n\x15\x63ursor_tuple_fraction\x18\n \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n\x13\x66rom_collapse_limit\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12J\n\x13join_collapse_limit\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x31-2147483647\x12q\n\x14\x64\x65\x62ug_parallel_query\x18\r \x01(\x0e\x32S.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.DebugParallelQuery\x12\x66\n\x13\x63lient_min_messages\x18\x0e \x01(\x0e\x32I.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.LogLevel\x12\x63\n\x10log_min_messages\x18\x0f \x01(\x0e\x32I.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.LogLevel\x12j\n\x17log_min_error_statement\x18\x10 \x01(\x0e\x32I.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.LogLevel\x12?\n\x1alog_min_duration_statement\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0flog_checkpoints\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0flog_connections\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_duration\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12o\n\x13log_error_verbosity\x18\x16 \x01(\x0e\x32R.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.LogErrorVerbosity\x12\x32\n\x0elog_lock_waits\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x64\n\rlog_statement\x18\x18 \x01(\x0e\x32M.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.LogStatement\x12\x33\n\x0elog_temp_files\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x13\n\x0bsearch_path\x18\x1a \x01(\t\x12\x30\n\x0crow_security\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12|\n\x1d\x64\x65\x66\x61ult_transaction_isolation\x18\x1c \x01(\x0e\x32U.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.TransactionIsolation\x12\x36\n\x11statement_timeout\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0clock_timeout\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n#idle_in_transaction_session_timeout\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12\x62\n\x0c\x62ytea_output\x18  \x01(\x0e\x32L.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.ByteaOutput\x12]\n\txmlbinary\x18! \x01(\x0e\x32J.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.XmlBinary\x12]\n\txmloption\x18\" \x01(\x0e\x32J.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.XmlOption\x12;\n\x16gin_pending_list_limit\x18# \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10\x64\x65\x61\x64lock_timeout\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_locks_per_transaction\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_pred_locks_per_transaction\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0b\x61rray_nulls\x18\' \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12h\n\x0f\x62\x61\x63kslash_quote\x18( \x01(\x0e\x32O.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1C.BackslashQuote\x12\x35\n\x11\x64\x65\x66\x61ult_with_oids\x18) \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15\x65scape_string_warning\x18* \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14lo_compat_privileges\x18+ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15quote_all_identifiers\x18- \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x1bstandard_conforming_strings\x18. \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14synchronize_seqscans\x18/ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15transform_null_equals\x18\x30 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rexit_on_error\x18\x31 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rseq_page_cost\x18\x32 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10random_page_cost\x18\x33 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x11\x65nable_bitmapscan\x18\x36 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_hashagg\x18\x37 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_hashjoin\x18\x38 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_indexscan\x18\x39 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14\x65nable_indexonlyscan\x18: \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_material\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x65nable_mergejoin\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65nable_nestloop\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_seqscan\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x65nable_sort\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x65nable_tidscan\x18@ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x14max_parallel_workers\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12P\n\x1fmax_parallel_workers_per_gather\x18\x42 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1024\x12\x10\n\x08timezone\x18\x43 \x01(\t\x12I\n\x18\x65\x66\x66\x65\x63tive_io_concurrency\x18\x44 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12M\n\x14\x65\x66\x66\x65\x63tive_cache_size\x18\x45 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-549755813888\"\x9a\x01\n\x0e\x42\x61\x63kslashQuote\x12\x1f\n\x1b\x42\x41\x43KSLASH_QUOTE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41\x43KSLASH_QUOTE\x10\x01\x12\x16\n\x12\x42\x41\x43KSLASH_QUOTE_ON\x10\x02\x12\x17\n\x13\x42\x41\x43KSLASH_QUOTE_OFF\x10\x03\x12!\n\x1d\x42\x41\x43KSLASH_QUOTE_SAFE_ENCODING\x10\x04\"[\n\x0b\x42yteaOutput\x12\x1c\n\x18\x42YTEA_OUTPUT_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42YTEA_OUTPUT_HEX\x10\x01\x12\x18\n\x14\x42YTEA_OUTPUT_ESCAPED\x10\x02\"\x9a\x01\n\x13\x43onstraintExclusion\x12$\n CONSTRAINT_EXCLUSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONSTRAINT_EXCLUSION_ON\x10\x01\x12\x1c\n\x18\x43ONSTRAINT_EXCLUSION_OFF\x10\x02\x12\"\n\x1e\x43ONSTRAINT_EXCLUSION_PARTITION\x10\x03\"\x97\x01\n\x12\x44\x65\x62ugParallelQuery\x12$\n DEBUG_PARALLEL_QUERY_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x44\x45\x42UG_PARALLEL_QUERY_ON\x10\x01\x12\x1c\n\x18\x44\x45\x42UG_PARALLEL_QUERY_OFF\x10\x02\x12 \n\x1c\x44\x45\x42UG_PARALLEL_QUERY_REGRESS\x10\x03\"\x92\x01\n\x11\x46orceParallelMode\x12#\n\x1f\x46ORCE_PARALLEL_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x46ORCE_PARALLEL_MODE_ON\x10\x01\x12\x1b\n\x17\x46ORCE_PARALLEL_MODE_OFF\x10\x02\x12\x1f\n\x1b\x46ORCE_PARALLEL_MODE_REGRESS\x10\x03\"\x99\x01\n\x11LogErrorVerbosity\x12#\n\x1fLOG_ERROR_VERBOSITY_UNSPECIFIED\x10\x00\x12\x1d\n\x19LOG_ERROR_VERBOSITY_TERSE\x10\x01\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_DEFAULT\x10\x02\x12\x1f\n\x1bLOG_ERROR_VERBOSITY_VERBOSE\x10\x03\"\xa6\x02\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\x14\n\x10LOG_LEVEL_DEBUG5\x10\x01\x12\x14\n\x10LOG_LEVEL_DEBUG4\x10\x02\x12\x14\n\x10LOG_LEVEL_DEBUG3\x10\x03\x12\x14\n\x10LOG_LEVEL_DEBUG2\x10\x04\x12\x14\n\x10LOG_LEVEL_DEBUG1\x10\x05\x12\x12\n\x0eLOG_LEVEL_INFO\x10\x0c\x12\x11\n\rLOG_LEVEL_LOG\x10\x06\x12\x14\n\x10LOG_LEVEL_NOTICE\x10\x07\x12\x15\n\x11LOG_LEVEL_WARNING\x10\x08\x12\x13\n\x0fLOG_LEVEL_ERROR\x10\t\x12\x13\n\x0fLOG_LEVEL_FATAL\x10\n\x12\x13\n\x0fLOG_LEVEL_PANIC\x10\x0b\"\x8a\x01\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x16\n\x12LOG_STATEMENT_NONE\x10\x01\x12\x15\n\x11LOG_STATEMENT_DDL\x10\x02\x12\x15\n\x11LOG_STATEMENT_MOD\x10\x03\x12\x15\n\x11LOG_STATEMENT_ALL\x10\x04\"\xe6\x01\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12*\n&TRANSACTION_ISOLATION_READ_UNCOMMITTED\x10\x01\x12(\n$TRANSACTION_ISOLATION_READ_COMMITTED\x10\x02\x12)\n%TRANSACTION_ISOLATION_REPEATABLE_READ\x10\x03\x12&\n\"TRANSACTION_ISOLATION_SERIALIZABLE\x10\x04\"R\n\tXmlBinary\x12\x1a\n\x16XML_BINARY_UNSPECIFIED\x10\x00\x12\x15\n\x11XML_BINARY_BASE64\x10\x01\x12\x12\n\x0eXML_BINARY_HEX\x10\x02\"X\n\tXmlOption\x12\x1a\n\x16XML_OPTION_UNSPECIFIED\x10\x00\x12\x17\n\x13XML_OPTION_DOCUMENT\x10\x01\x12\x16\n\x12XML_OPTION_CONTENT\x10\x02J\x04\x08\x34\x10\x36J\x04\x08,\x10-B\x81\x01\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.config.host16_1c_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.mdb.postgresql.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1/config;postgresql'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['backend_flush_after']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['backend_flush_after']._serialized_options = b'\372\3071\0060-2048'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['old_snapshot_threshold']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['old_snapshot_threshold']._serialized_options = b'\372\3071\010-1-86400'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['from_collapse_limit']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['from_collapse_limit']._serialized_options = b'\372\3071\0141-2147483647'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['join_collapse_limit']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['join_collapse_limit']._serialized_options = b'\372\3071\0141-2147483647'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['idle_in_transaction_session_timeout']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['max_parallel_workers']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['max_parallel_workers']._serialized_options = b'\372\3071\0060-1024'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['max_parallel_workers_per_gather']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['max_parallel_workers_per_gather']._serialized_options = b'\372\3071\0060-1024'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['effective_io_concurrency']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['effective_io_concurrency']._serialized_options = b'\372\3071\0060-1000'
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['effective_cache_size']._options = None
  _POSTGRESQLHOSTCONFIG16_1C.fields_by_name['effective_cache_size']._serialized_options = b'\372\3071\0160-549755813888'
  _globals['_POSTGRESQLHOSTCONFIG16_1C']._serialized_start=160
  _globals['_POSTGRESQLHOSTCONFIG16_1C']._serialized_end=6316
  _globals['_POSTGRESQLHOSTCONFIG16_1C_BACKSLASHQUOTE']._serialized_start=4596
  _globals['_POSTGRESQLHOSTCONFIG16_1C_BACKSLASHQUOTE']._serialized_end=4750
  _globals['_POSTGRESQLHOSTCONFIG16_1C_BYTEAOUTPUT']._serialized_start=4752
  _globals['_POSTGRESQLHOSTCONFIG16_1C_BYTEAOUTPUT']._serialized_end=4843
  _globals['_POSTGRESQLHOSTCONFIG16_1C_CONSTRAINTEXCLUSION']._serialized_start=4846
  _globals['_POSTGRESQLHOSTCONFIG16_1C_CONSTRAINTEXCLUSION']._serialized_end=5000
  _globals['_POSTGRESQLHOSTCONFIG16_1C_DEBUGPARALLELQUERY']._serialized_start=5003
  _globals['_POSTGRESQLHOSTCONFIG16_1C_DEBUGPARALLELQUERY']._serialized_end=5154
  _globals['_POSTGRESQLHOSTCONFIG16_1C_FORCEPARALLELMODE']._serialized_start=5157
  _globals['_POSTGRESQLHOSTCONFIG16_1C_FORCEPARALLELMODE']._serialized_end=5303
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGERRORVERBOSITY']._serialized_start=5306
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGERRORVERBOSITY']._serialized_end=5459
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGLEVEL']._serialized_start=5462
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGLEVEL']._serialized_end=5756
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGSTATEMENT']._serialized_start=5759
  _globals['_POSTGRESQLHOSTCONFIG16_1C_LOGSTATEMENT']._serialized_end=5897
  _globals['_POSTGRESQLHOSTCONFIG16_1C_TRANSACTIONISOLATION']._serialized_start=5900
  _globals['_POSTGRESQLHOSTCONFIG16_1C_TRANSACTIONISOLATION']._serialized_end=6130
  _globals['_POSTGRESQLHOSTCONFIG16_1C_XMLBINARY']._serialized_start=6132
  _globals['_POSTGRESQLHOSTCONFIG16_1C_XMLBINARY']._serialized_end=6214
  _globals['_POSTGRESQLHOSTCONFIG16_1C_XMLOPTION']._serialized_start=6216
  _globals['_POSTGRESQLHOSTCONFIG16_1C_XMLOPTION']._serialized_end=6304
# @@protoc_insertion_point(module_scope)
